@@ -661,70 +661,6 @@ int ext2_commit_metadata(struct ext2_fs *fs, int copies)
 	return 1;
 }
 
-static int ext2_determine_itoffset(struct ext2_fs *fs)
-{
-	int i;
-
-	fs->itoffset = EXT2_GROUP_INODE_TABLE(fs->gd[0])
-		       - EXT2_SUPER_FIRST_DATA_BLOCK(fs->sb);
-
-        /*PED_DEBUG (0x20, "itoffset is %d", fs->itoffset);
-        
-        PED_DEBUG (0x20, "walking %d groups", fs->numgroups);*/
-
-	for (i=0;i<fs->numgroups;i++)
-	{
-		blk_t start;
-		blk_t bb;
-		blk_t ib;
-		blk_t it;
-
-		start = EXT2_SUPER_FIRST_DATA_BLOCK(fs->sb)
-			+ (i * EXT2_SUPER_BLOCKS_PER_GROUP(fs->sb));
-		it = start + fs->itoffset;
-
-                /*PED_DEBUG (0x21, "start = %d, it = %d", start, it);*/
-
-		if (ext2_is_group_sparse(fs, i))
-		{
-                        /*PED_DEBUG (0x21, "%d has a superblock copy", i);*/
-			bb = it - 2;
-			ib = it - 1;
-		}
-		else
-		{
-                        /*PED_DEBUG (0x21, "%d doesn't have a superblock copy",
-                            i);*/
-			bb = start;
-			ib = start + 1;
-		}
-
-		if (EXT2_GROUP_BLOCK_BITMAP(fs->gd[i]) != bb ||
-		    EXT2_GROUP_INODE_BITMAP(fs->gd[i]) != ib ||
-		    EXT2_GROUP_INODE_TABLE(fs->gd[i]) != it)
-		{
-		/*	ped_exception_throw (PED_EXCEPTION_NO_FEATURE,
-				PED_EXCEPTION_CANCEL,
-			_("This ext2 file system has a rather strange layout!  "
-			  "Parted can't resize this (yet)."));*/
-
-                 /*       PED_DEBUG (0x21, "calculated block bitmap to be %d, "
-                                         "but fs says %d.", bb,
-                                         EXT2_GROUP_BLOCK_BITMAP(fs->gd[i]));
-                        PED_DEBUG (0x21, "calculated inode bitmap to be %d, "
-                                         "but fs says %d.", ib,
-                                         EXT2_GROUP_INODE_BITMAP(fs->gd[i]));
-                        PED_DEBUG (0x21, "calculated inode table to be %d, "
-                                         "but fs says %d.", it,
-                                         EXT2_GROUP_INODE_TABLE(fs->gd[i]));*/
-                        
-			return 0;
-		}
-	}
-
-	return 1;
-}
-
 int ext2_sync(struct ext2_fs *fs)
 {
 	if (!ext2_commit_metadata(fs, EXT2_META_PRIMARY)) return 0;
@@ -841,21 +777,6 @@ struct ext2_fs *ext2_open(struct ext2_dev_handle *handle, int state)
 
 	ext2_read_blocks(fs, fs->gd, EXT2_SUPER_FIRST_DATA_BLOCK(fs->sb) + 1,
 			 fs->gdblocks);
-
-	if (!ext2_determine_itoffset(fs) && ped_exception_throw (
-                        PED_EXCEPTION_WARNING,
-                        PED_EXCEPTION_OK_CANCEL,
-                        _("A resize operation on this file system will "
-                          "use EXPERIMENTAL code\n"
-                          "that MAY CORRUPT it (although it hasn't done"
-                          "so yet\n"
-                          "in the past).\n"
-                          "You should at least backup your data and "
-                          "run 'e2fsck -f' afterwards."))
-                == PED_EXCEPTION_CANCEL)
-        {
-	        goto error_free_gd;
-        }
                 
 	fs->metadirty = 0;
 	return fs;
